==> knative-model-6.3.1-sources.jar: io/fabric8/knative/serving/v1/RevisionTemplateSpecFluentImpl.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RevisionTemplateSpecFluentImpl<A extends RevisionTemplateSpecFluent<A>> extends BaseFluent<A> implements RevisionTemplateSpecFluent<A>{
  public RevisionTemplateSpecFluentImpl() {
  }
  public RevisionTemplateSpecFluentImpl(RevisionTemplateSpec instance) {
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
  }
  private ObjectMetaBuilder metadata;
  private RevisionSpecBuilder spec;
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public RevisionTemplateSpecFluent.MetadataNested<A> withNewMetadata() {
    return new RevisionTemplateSpecFluentImpl.MetadataNestedImpl();
  }
  public RevisionTemplateSpecFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new RevisionTemplateSpecFluentImpl.MetadataNestedImpl(item);
  }
  public RevisionTemplateSpecFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public RevisionTemplateSpecFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public RevisionTemplateSpecFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public RevisionSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public RevisionSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(RevisionSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new RevisionSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public RevisionTemplateSpecFluent.SpecNested<A> withNewSpec() {
    return new RevisionTemplateSpecFluentImpl.SpecNestedImpl();
  }
  public RevisionTemplateSpecFluent.SpecNested<A> withNewSpecLike(RevisionSpec item) {
    return new RevisionTemplateSpecFluentImpl.SpecNestedImpl(item);
  }
  public RevisionTemplateSpecFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public RevisionTemplateSpecFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new RevisionSpecBuilder().build());
  }
  public RevisionTemplateSpecFluent.SpecNested<A> editOrNewSpecLike(RevisionSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RevisionTemplateSpecFluentImpl that = (RevisionTemplateSpecFluentImpl) o;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  spec,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<RevisionTemplateSpecFluent.MetadataNested<N>> implements RevisionTemplateSpecFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) RevisionTemplateSpecFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends RevisionSpecFluentImpl<RevisionTemplateSpecFluent.SpecNested<N>> implements RevisionTemplateSpecFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(RevisionSpec item) {
      this.builder = new RevisionSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new RevisionSpecBuilder(this);
    }
    RevisionSpecBuilder builder;
    public N and() {
      return (N) RevisionTemplateSpecFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/serving/v1/RevisionTemplateSpecFluentImpl.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RevisionTemplateSpecFluentImpl<A extends RevisionTemplateSpecFluent<A>> extends BaseFluent<A> implements RevisionTemplateSpecFluent<A>{
  public RevisionTemplateSpecFluentImpl() {
  }
  public RevisionTemplateSpecFluentImpl(RevisionTemplateSpec instance) {
    if (instance != null) {
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
    }
  }
  private ObjectMetaBuilder metadata;
  private RevisionSpecBuilder spec;
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public RevisionTemplateSpecFluentImpl.MetadataNested<A> withNewMetadata() {
    return new RevisionTemplateSpecFluentImpl.MetadataNestedImpl();
  }
  public RevisionTemplateSpecFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new RevisionTemplateSpecFluentImpl.MetadataNestedImpl(item);
  }
  public RevisionTemplateSpecFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public RevisionTemplateSpecFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public RevisionTemplateSpecFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public RevisionSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public RevisionSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(RevisionSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new RevisionSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public RevisionTemplateSpecFluentImpl.SpecNested<A> withNewSpec() {
    return new RevisionTemplateSpecFluentImpl.SpecNestedImpl();
  }
  public RevisionTemplateSpecFluentImpl.SpecNested<A> withNewSpecLike(RevisionSpec item) {
    return new RevisionTemplateSpecFluentImpl.SpecNestedImpl(item);
  }
  public RevisionTemplateSpecFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public RevisionTemplateSpecFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new RevisionSpecBuilder().build());
  }
  public RevisionTemplateSpecFluentImpl.SpecNested<A> editOrNewSpecLike(RevisionSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RevisionTemplateSpecFluentImpl that = (RevisionTemplateSpecFluentImpl) o;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  spec,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<RevisionTemplateSpecFluentImpl.MetadataNested<N>> implements RevisionTemplateSpecFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) RevisionTemplateSpecFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends RevisionSpecFluentImpl<RevisionTemplateSpecFluentImpl.SpecNested<N>> implements RevisionTemplateSpecFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(RevisionSpec item) {
      this.builder = new RevisionSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new RevisionSpecBuilder(this);
    }
    RevisionSpecBuilder builder;
    public N and() {
      return (N) RevisionTemplateSpecFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}
